<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>GeoServiceProviderFactoryEsri</name>
    <message>
        <source>Esri plugin requires a &apos;esri.token&apos; parameter.
Please visit https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</source>
        <translation>El connector Esri requereix un paràmetre «esri.token».
Visiteu https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</translation>
    </message>
</context>
<context>
    <name>PlaceSearchReplyEsri</name>
    <message>
        <source>Response parse error</source>
        <translation>Error en analitzar la resposta</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoMap</name>
    <message>
        <source>No Map</source>
        <translation>Sense mapa</translation>
    </message>
    <message>
        <source>Plugin does not support mapping.</source>
        <translation>El connector no admet el mapatge.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoRouteModel</name>
    <message>
        <source>Plugin does not support routing.</source>
        <translation>El connector no admet itineraris.</translation>
    </message>
    <message>
        <source>Cannot route, plugin not set.</source>
        <translation>No s&apos;ha pogut calcular l&apos;itinerari, no s&apos;ha definit el connector.</translation>
    </message>
    <message>
        <source>Cannot route, route manager not set.</source>
        <translation>No s&apos;ha pogut calcular l&apos;itinerari, no s&apos;ha definit el gestor d&apos;itineraris.</translation>
    </message>
    <message>
        <source>Cannot route, valid query not set.</source>
        <translation>No s&apos;ha pogut calcular l&apos;itinerari, no s&apos;ha definit cap consulta vàlida.</translation>
    </message>
    <message>
        <source>Not enough waypoints for routing.</source>
        <translation>No hi ha punts de ruta suficients per a calcular l&apos;itinerari.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeocodeModel</name>
    <message>
        <source>Cannot geocode, plugin not set.</source>
        <translation>No s&apos;ha pogut geocodificar, no s&apos;ha establert el connector.</translation>
    </message>
    <message>
        <source>Cannot geocode, geocode manager not set.</source>
        <translation>No s&apos;ha pogut geocodificar, no s&apos;ha establert el gestor de la geocodificació.</translation>
    </message>
    <message>
        <source>Cannot geocode, valid query not set.</source>
        <translation>No s&apos;ha pogut geocodificar, no s&apos;ha establert una consulta vàlida.</translation>
    </message>
    <message>
        <source>Plugin does not support (reverse) geocoding.</source>
        <translation>El connector no admet la geocodificació (inversa).</translation>
    </message>
</context>
<context>
    <name>QDeclarativeNavigator</name>
    <message>
        <source>Plugin does not support navigation.</source>
        <translation type="vanished">El connector no admet navegació.</translation>
    </message>
    <message>
        <source>Failed to create a navigator object.</source>
        <translation type="vanished">Ha fallat en crear un objecte navegador.</translation>
    </message>
</context>
<context>
    <name>QGeoCodeReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Error en analitzar la resposta</translation>
    </message>
</context>
<context>
    <name>QGeoMapMapboxGL</name>
    <message>
        <source>Development access token, do not use in production.</source>
        <translation>Testimoni d&apos;accés de desenvolupament. No utilitzeu en producció.</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineItemsOverlay</name>
    <message>
        <source>Empty Map</source>
        <translation>Mapa buit</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineMapboxGL</name>
    <message>
        <source>China Streets</source>
        <translation>Carrers de la Xina</translation>
    </message>
    <message>
        <source>China Light</source>
        <translation>Xina clar</translation>
    </message>
    <message>
        <source>China Dark</source>
        <translation>Xina fosc</translation>
    </message>
    <message>
        <source>Streets</source>
        <translation>Carrers</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Bàsic</translation>
    </message>
    <message>
        <source>Bright</source>
        <translation>Brillant</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <translation>Exteriors</translation>
    </message>
    <message>
        <source>Satellite</source>
        <translation>Satèl·lit</translation>
    </message>
    <message>
        <source>Satellite Streets</source>
        <translation>Carrers des de satèl·lit</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Clar</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Fosc</translation>
    </message>
    <message>
        <source>Navigation Preview Day</source>
        <translation>Vista prèvia de la navegació de dia</translation>
    </message>
    <message>
        <source>Navigation Preview Night</source>
        <translation>Vista prèvia de la navegació de nit</translation>
    </message>
    <message>
        <source>Navigation Guidance Day</source>
        <translation>Guia de la navegació de dia</translation>
    </message>
    <message>
        <source>Navigation Guidance Night</source>
        <translation>Guia de la navegació de nit</translation>
    </message>
    <message>
        <source>User provided style</source>
        <translation>Estil proporcionat per l&apos;usuari</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV4</name>
    <message>
        <source>Go straight.</source>
        <translation>Segueix recte.</translation>
    </message>
    <message>
        <source>Go straight onto %1.</source>
        <translation>Segueix recte a %1.</translation>
    </message>
    <message>
        <source>Turn slightly right.</source>
        <translation>Gira lleugerament a la dreta.</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1.</source>
        <translation>Gira lleugerament a la dreta a %1.</translation>
    </message>
    <message>
        <source>Turn right.</source>
        <translation>Gira a la dreta.</translation>
    </message>
    <message>
        <source>Turn right onto %1.</source>
        <translation>Gira a la dreta a %1.</translation>
    </message>
    <message>
        <source>Make a sharp right.</source>
        <translation>Gira pronunciadament a la dreta.</translation>
    </message>
    <message>
        <source>Make a sharp right onto %1.</source>
        <translation>Gira pronunciadament a la dreta a %1.</translation>
    </message>
    <message>
        <source>When it is safe to do so, perform a U-turn.</source>
        <translation>Quan sigui segur, realitzeu un canvi de sentit.</translation>
    </message>
    <message>
        <source>Make a sharp left.</source>
        <translation>Gira pronunciadament a l&apos;esquerra.</translation>
    </message>
    <message>
        <source>Make a sharp left onto %1.</source>
        <translation>Gira pronunciadament a l&apos;esquerra a %1.</translation>
    </message>
    <message>
        <source>Turn left.</source>
        <translation>Gira a l&apos;esquerra.</translation>
    </message>
    <message>
        <source>Turn left onto %1.</source>
        <translation>Gira a l&apos;esquerra a %1.</translation>
    </message>
    <message>
        <source>Turn slightly left.</source>
        <translation>Gira lleugerament a l&apos;esquerra.</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1.</source>
        <translation>Gira lleugerament a l&apos;esquerra a %1.</translation>
    </message>
    <message>
        <source>Reached waypoint.</source>
        <translation>S&apos;ha arribat al punt de ruta.</translation>
    </message>
    <message>
        <source>Head on.</source>
        <translation>Cap endavant.</translation>
    </message>
    <message>
        <source>Head onto %1.</source>
        <translation>Cap endavant a %1.</translation>
    </message>
    <message>
        <source>Enter the roundabout.</source>
        <translation>Entra a la rotonda.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit.</source>
        <translation>A la rotonda agafa la primera sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit onto %1.</source>
        <translation>A la rotonda agafa la primera sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit.</source>
        <translation>A la rotonda agafa la segona sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit onto %1.</source>
        <translation>A la rotonda agafa la segona sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit.</source>
        <translation>A la rotonda agafa la tercera sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit onto %1.</source>
        <translation>A la rotonda agafa la tercera sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit.</source>
        <translation>A la rotonda agafa la quarta sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit onto %1.</source>
        <translation>A la rotonda agafa la quarta sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit.</source>
        <translation>A la rotonda agafa la cinquena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit onto %1.</source>
        <translation>A la rotonda agafa la cinquena sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit.</source>
        <translation>A la rotonda agafa la sisena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit onto %1.</source>
        <translation>A la rotonda agafa la sisena sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit.</source>
        <translation>A la rotonda agafa la setena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit onto %1.</source>
        <translation>A la rotonda agafa la setena sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit.</source>
        <translation>A la rotonda agafa la vuitena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit onto %1.</source>
        <translation>A la rotonda agafa la vuitena sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit.</source>
        <translation>A la rotonda agafa la novena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit onto %1.</source>
        <translation>A la rotonda agafa la novena sortida a %1.</translation>
    </message>
    <message>
        <source>Leave the roundabout.</source>
        <translation>Surt de la rotonda.</translation>
    </message>
    <message>
        <source>Leave the roundabout onto %1.</source>
        <translation>Surt de la rotonda a %1.</translation>
    </message>
    <message>
        <source>Stay on the roundabout.</source>
        <translation>Roman a la rotonda.</translation>
    </message>
    <message>
        <source>Start at the end of the street.</source>
        <translation>Comença al final del carrer.</translation>
    </message>
    <message>
        <source>Start at the end of %1.</source>
        <translation>Comença al final de %1.</translation>
    </message>
    <message>
        <source>You have reached your destination.</source>
        <translation>Has arribat a la teva destinació.</translation>
    </message>
    <message>
        <source>Don&apos;t know what to say for &apos;%1&apos;</source>
        <translation>No sé què dir per a «%1»</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV5</name>
    <message>
        <source>North</source>
        <extracomment>Translations exist at https://github.com/Project-OSRM/osrm-text-instructions. Always used in &quot;Head %1 [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>nord</translation>
    </message>
    <message>
        <source>East</source>
        <translation>est</translation>
    </message>
    <message>
        <source>South</source>
        <translation>sud</translation>
    </message>
    <message>
        <source>West</source>
        <translation>oest</translation>
    </message>
    <message>
        <source>first</source>
        <comment>roundabout exit</comment>
        <extracomment>always used in &quot; and take the %1 exit [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>primera</translation>
    </message>
    <message>
        <source>second</source>
        <comment>roundabout exit</comment>
        <translation>segona</translation>
    </message>
    <message>
        <source>third</source>
        <comment>roundabout exit</comment>
        <translation>tercera</translation>
    </message>
    <message>
        <source>fourth</source>
        <comment>roundabout exit</comment>
        <translation>quarta</translation>
    </message>
    <message>
        <source>fifth</source>
        <comment>roundabout exit</comment>
        <translation>cinquena</translation>
    </message>
    <message>
        <source>sixth</source>
        <comment>roundabout exit</comment>
        <translation>sisena</translation>
    </message>
    <message>
        <source>seventh</source>
        <comment>roundabout exit</comment>
        <translation>setena</translation>
    </message>
    <message>
        <source>eighth</source>
        <comment>roundabout exit</comment>
        <translation>vuitena</translation>
    </message>
    <message>
        <source>ninth</source>
        <comment>roundabout exit</comment>
        <translation>novena</translation>
    </message>
    <message>
        <source>tenth</source>
        <comment>roundabout exit</comment>
        <translation>desena</translation>
    </message>
    <message>
        <source>eleventh</source>
        <comment>roundabout exit</comment>
        <translation>onzena</translation>
    </message>
    <message>
        <source>twelfth</source>
        <comment>roundabout exit</comment>
        <translation>dotzena</translation>
    </message>
    <message>
        <source>thirteenth</source>
        <comment>roundabout exit</comment>
        <translation>tretzena</translation>
    </message>
    <message>
        <source>fourteenth</source>
        <comment>roundabout exit</comment>
        <translation>catorzena</translation>
    </message>
    <message>
        <source>fifteenth</source>
        <comment>roundabout exit</comment>
        <translation>quinzena</translation>
    </message>
    <message>
        <source>sixteenth</source>
        <comment>roundabout exit</comment>
        <translation>setzena</translation>
    </message>
    <message>
        <source>seventeenth</source>
        <comment>roundabout exit</comment>
        <translation>dissetena</translation>
    </message>
    <message>
        <source>eighteenth</source>
        <comment>roundabout exit</comment>
        <translation>divuitena</translation>
    </message>
    <message>
        <source>nineteenth</source>
        <comment>roundabout exit</comment>
        <translation>dinovena</translation>
    </message>
    <message>
        <source>twentieth</source>
        <comment>roundabout exit</comment>
        <translation>vintena</translation>
    </message>
    <message>
        <source> and take the %1 exit</source>
        <extracomment>Always appended to one of the following strings: - &quot;Enter the roundabout&quot; - &quot;Enter the rotary&quot; - &quot;Enter the rotary &lt;rotaryname&gt;&quot;</extracomment>
        <translation> i agafa la %1 sortida</translation>
    </message>
    <message>
        <source> and take the %1 exit onto %2</source>
        <translation> i agafa la %1 sortida a %2</translation>
    </message>
    <message>
        <source>You have arrived at your destination, straight ahead</source>
        <translation>Has arribat a la teva destinació, tot recte</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the left</source>
        <translation>Has arribat a la teva destinació, a l&apos;esquerra</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the right</source>
        <translation>Has arribat a la teva destinació, a la dreta</translation>
    </message>
    <message>
        <source>You have arrived at your destination</source>
        <translation>Has arribat a la teva destinació</translation>
    </message>
    <message>
        <source>Continue straight</source>
        <translation>Segueix recte</translation>
    </message>
    <message>
        <source>Continue straight on %1</source>
        <translation>Segueix recte a %1</translation>
    </message>
    <message>
        <source>Continue left</source>
        <translation>Continua a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Continue left onto %1</source>
        <translation>Continua a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Continue slightly left</source>
        <translation>Continua lleugerament a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Continue slightly left on %1</source>
        <translation>Continua lleugerament a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Continue right</source>
        <translation>Continua a la dreta</translation>
    </message>
    <message>
        <source>Continue right onto %1</source>
        <translation>Continua a la dreta a %1</translation>
    </message>
    <message>
        <source>Continue slightly right</source>
        <translation>Continua lleugerament a la dreta</translation>
    </message>
    <message>
        <source>Continue slightly right on %1</source>
        <translation>Continua lleugerament a la dreta a %1</translation>
    </message>
    <message>
        <source>Make a U-turn</source>
        <translation>Fes un canvi de sentit</translation>
    </message>
    <message>
        <source>Make a U-turn onto %1</source>
        <translation>Fes un canvi de sentit a %1</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Continue on %1</source>
        <translation>Continua a %1</translation>
    </message>
    <message>
        <source>Head %1</source>
        <extracomment>%1 is &quot;North&quot;, &quot;South&quot;, &quot;East&quot; or &quot;West&quot;</extracomment>
        <translation>Direcció %1</translation>
    </message>
    <message>
        <source>Head %1 onto %2</source>
        <translation>Direcció %1 a %2</translation>
    </message>
    <message>
        <source>Depart</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <source>Depart onto %1</source>
        <translation>Sortida a %1</translation>
    </message>
    <message>
        <source>At the end of the road, turn left</source>
        <translation>Al final de la carretera, gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>At the end of the road, turn left onto %1</source>
        <translation>Al final de la carretera, gira a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>At the end of the road, turn right</source>
        <translation>Al final de la carretera, gira a la dreta</translation>
    </message>
    <message>
        <source>At the end of the road, turn right onto %1</source>
        <translation>Al final de la carretera, gira a la dreta a %1</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn</source>
        <translation>Al final de la carretera, fes un canvi de sentit</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn onto %1</source>
        <translation>Al final de la carretera, fes un canvi de sentit a %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight</source>
        <translation>Al final de la carretera, continua recte</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight onto %1</source>
        <translation>Al final de la carretera, continua recte a %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue</source>
        <translation>Al final de la carretera, continua</translation>
    </message>
    <message>
        <source>At the end of the road, continue onto %1</source>
        <translation>Al final de la carretera, continua a %1</translation>
    </message>
    <message>
        <source>Take the ferry</source>
        <translation>Agafa el transbordador</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left</source>
        <translation>A la bifurcació, fes un gir pronunciat a l&apos;esquerra</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left onto %1</source>
        <translation>A la bifurcació, fes un gir pronunciat a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>At the fork, turn left</source>
        <translation>A la bifurcació, gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>At the fork, turn left onto %1</source>
        <translation>A la bifurcació, gira a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>At the fork, keep left</source>
        <translation>A la bifurcació, mantén l&apos;esquerra</translation>
    </message>
    <message>
        <source>At the fork, keep left onto %1</source>
        <translation>A la bifurcació, mantén l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right</source>
        <translation>A la bifurcació, fes un gir pronunciat a la dreta</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right onto %1</source>
        <translation>A la bifurcació, fes un gir pronunciat a la dreta a %1</translation>
    </message>
    <message>
        <source>At the fork, turn right</source>
        <translation>A la bifurcació, gira a la dreta</translation>
    </message>
    <message>
        <source>At the fork, turn right onto %1</source>
        <translation>A la bifurcació, gira a la dreta a %1</translation>
    </message>
    <message>
        <source>At the fork, keep right</source>
        <translation>A la bifurcació, mantén la dreta</translation>
    </message>
    <message>
        <source>At the fork, keep right onto %1</source>
        <translation>A la bifurcació, mantén la dreta a %1</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead</source>
        <translation>A la bifurcació, continua recte</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead onto %1</source>
        <translation>A la bifurcació, continua recte a %1</translation>
    </message>
    <message>
        <source>At the fork, continue</source>
        <translation>A la bifurcació, continua</translation>
    </message>
    <message>
        <source>At the fork, continue onto %1</source>
        <translation>A la bifurcació, continua a %1</translation>
    </message>
    <message>
        <source>Merge sharply left</source>
        <translation>Unió pronunciada a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Merge sharply left onto %1</source>
        <translation>Unió pronunciada a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Merge left</source>
        <translation>Unió a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Merge left onto %1</source>
        <translation>Unió a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Merge slightly left</source>
        <translation>Unió lleugerament a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Merge slightly left on %1</source>
        <translation>Unió lleugerament a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Merge sharply right</source>
        <translation>Unió pronunciada a la dreta</translation>
    </message>
    <message>
        <source>Merge sharply right onto %1</source>
        <translation>Unió pronunciada a la dreta a %1</translation>
    </message>
    <message>
        <source>Merge right</source>
        <translation>Unió a la dreta</translation>
    </message>
    <message>
        <source>Merge right onto %1</source>
        <translation>Unió a la dreta a %1</translation>
    </message>
    <message>
        <source>Merge slightly right</source>
        <translation>Unió lleugerament a la dreta</translation>
    </message>
    <message>
        <source>Merge slightly right on %1</source>
        <translation>Unió lleugerament a la dreta a %1</translation>
    </message>
    <message>
        <source>Merge straight</source>
        <translation>Unió recta</translation>
    </message>
    <message>
        <source>Merge straight on %1</source>
        <translation>Unió recta a %1</translation>
    </message>
    <message>
        <source>Merge</source>
        <translation>Unió</translation>
    </message>
    <message>
        <source>Merge onto %1</source>
        <translation>Unió a %1</translation>
    </message>
    <message>
        <source>Take a sharp left</source>
        <translation>Agafa pronunciadament a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Take a sharp left onto %1</source>
        <translation>Agafa pronunciadament a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Turn left</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Turn left onto %1</source>
        <translation>Gira a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Continue slightly left onto %1</source>
        <translation>Continua lleugerament a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Take a sharp right</source>
        <translation>Gira pronunciadament a la dreta</translation>
    </message>
    <message>
        <source>Take a sharp right onto %1</source>
        <translation>Gira pronunciadament a la dreta a %1</translation>
    </message>
    <message>
        <source>Turn right</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Turn right onto %1</source>
        <translation>Gira a la dreta a %1</translation>
    </message>
    <message>
        <source>Continue slightly right onto %1</source>
        <translation>Continua lleugerament a la dreta a %1</translation>
    </message>
    <message>
        <source>Continue straight onto %1</source>
        <translation>Continua recte a %1</translation>
    </message>
    <message>
        <source>Continue onto %1</source>
        <translation>Continua a %1</translation>
    </message>
    <message>
        <source>Continue on the left</source>
        <translation>Continua a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Continue on the left on %1</source>
        <translation>Continua a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Continue on the right</source>
        <translation>Continua a la dreta</translation>
    </message>
    <message>
        <source>Continue on the right on %1</source>
        <translation>Continua a la dreta a %1</translation>
    </message>
    <message>
        <source>Take the ramp on the left</source>
        <translation>Agafa la rampa de l&apos;esquerra</translation>
    </message>
    <message>
        <source>Take the ramp on the left onto %1</source>
        <translation>Agafa la rampa de l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Take the ramp on the right</source>
        <translation>Agafa la rampa de la dreta</translation>
    </message>
    <message>
        <source>Take the ramp on the right onto %1</source>
        <translation>Agafa la rampa de la dreta a %1</translation>
    </message>
    <message>
        <source>Take the ramp</source>
        <translation>Agafa la rampa</translation>
    </message>
    <message>
        <source>Take the ramp onto %1</source>
        <translation>Agafa la rampa a %1</translation>
    </message>
    <message>
        <source>Get off the bike and push</source>
        <translation>Baixa de la bicicleta i empeny</translation>
    </message>
    <message>
        <source>Get off the bike and push onto %1</source>
        <translation>Baixa de la bicicleta i empeny a %1</translation>
    </message>
    <message>
        <source>Enter the rotary</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Entra a la rotonda</translation>
    </message>
    <message>
        <source>Enter the roundabout</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Entra a la rotonda</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight</source>
        <translation>A la rotonda, continua recte</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight on %1</source>
        <translation>A la rotonda, continua recte a %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn left</source>
        <translation>A la rotonda, gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>At the roundabout, turn left onto %1</source>
        <translation>A la rotonda, gira a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn right</source>
        <translation>A la rotonda, gira a la dreta</translation>
    </message>
    <message>
        <source>At the roundabout, turn right onto %1</source>
        <translation>A la rotonda, gira a la dreta a %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn around</source>
        <translation>A la rotonda, dona la volta</translation>
    </message>
    <message>
        <source>At the roundabout, turn around onto %1</source>
        <translation>A la rotonda, dona la volta a %1</translation>
    </message>
    <message>
        <source>At the roundabout, continue</source>
        <translation>A la rotonda, continua</translation>
    </message>
    <message>
        <source>At the roundabout, continue onto %1</source>
        <translation>A la rotonda, continua a %1</translation>
    </message>
    <message>
        <source>Take the train</source>
        <translation>Agafa el tren</translation>
    </message>
    <message>
        <source>Take the train [%1]</source>
        <translation>Agafa el tren [%1]</translation>
    </message>
    <message>
        <source>Go straight</source>
        <translation>Segueix recte</translation>
    </message>
    <message>
        <source>Go straight onto %1</source>
        <translation>Segueix recte a %1</translation>
    </message>
    <message>
        <source>Turn slightly left</source>
        <translation>Gira lleugerament a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1</source>
        <translation>Gira lleugerament a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source>Turn slightly right</source>
        <translation>Gira lleugerament a la dreta</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1</source>
        <translation>Gira lleugerament a la dreta a %1</translation>
    </message>
    <message>
        <source>Turn</source>
        <translation>Gira</translation>
    </message>
    <message>
        <source>Turn onto %1</source>
        <translation>Gira a %1</translation>
    </message>
    <message>
        <source> and continue straight</source>
        <extracomment>This string will be prepended with lane instructions. E.g., &quot;Use the left or the right lane and continue straight&quot;</extracomment>
        <translation> i continua recte</translation>
    </message>
    <message>
        <source> and continue straight onto %1</source>
        <translation> i continua recte a %1</translation>
    </message>
    <message>
        <source> and make a sharp left</source>
        <translation> i gira pronunciadament a l&apos;esquerra</translation>
    </message>
    <message>
        <source> and make a sharp left onto %1</source>
        <translation> i gira pronunciadament a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source> and turn left</source>
        <translation> i gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source> and turn left onto %1</source>
        <translation> i gira a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source> and make a slight left</source>
        <translation> i gira lleugerament a l&apos;esquerra</translation>
    </message>
    <message>
        <source> and make a slight left onto %1</source>
        <translation> i gira lleugerament a l&apos;esquerra a %1</translation>
    </message>
    <message>
        <source> and make a sharp right</source>
        <translation> i gira pronunciadament a la dreta</translation>
    </message>
    <message>
        <source> and make a sharp right onto %1</source>
        <translation> i gira lleugerament a la dreta a %1</translation>
    </message>
    <message>
        <source> and turn right</source>
        <translation> i gira a la dreta</translation>
    </message>
    <message>
        <source> and turn right onto %1</source>
        <translation> i gira a la dreta a %1</translation>
    </message>
    <message>
        <source> and make a slight right</source>
        <translation> i gira lleugerament a la dreta</translation>
    </message>
    <message>
        <source> and make a slight right onto %1</source>
        <translation> i gira lleugerament a la dreta a %1</translation>
    </message>
    <message>
        <source> and make a U-turn</source>
        <translation> i fes un canvi de sentit</translation>
    </message>
    <message>
        <source> and make a U-turn onto %1</source>
        <translation> i fes un canvi de sentit a %1</translation>
    </message>
</context>
<context>
    <name>QGeoRouteReplyOsm</name>
    <message>
        <source>Go straight.</source>
        <translation type="vanished">Segueix dret.</translation>
    </message>
    <message>
        <source>Go straight onto %1.</source>
        <translation type="vanished">Segueix dret a %1.</translation>
    </message>
    <message>
        <source>Turn slightly right.</source>
        <translation type="vanished">Gira lleugerament a la dreta.</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1.</source>
        <translation type="vanished">Gira lleugerament a la dreta a %1.</translation>
    </message>
    <message>
        <source>Turn right.</source>
        <translation type="vanished">Gira a la dreta.</translation>
    </message>
    <message>
        <source>Turn right onto %1.</source>
        <translation type="vanished">Gira a la dreta a %1.</translation>
    </message>
    <message>
        <source>Make a sharp right.</source>
        <translation type="vanished">Gira fort a la dreta.</translation>
    </message>
    <message>
        <source>Make a sharp right onto %1.</source>
        <translation type="vanished">Gira fort a la dreta a %1.</translation>
    </message>
    <message>
        <source>When it is safe to do so, perform a U-turn.</source>
        <translation type="vanished">Quan sigui segur, realitzeu un canvi de sentit.</translation>
    </message>
    <message>
        <source>Make a sharp left.</source>
        <translation type="vanished">Gira fort a l&apos;esquerra.</translation>
    </message>
    <message>
        <source>Make a sharp left onto %1.</source>
        <translation type="vanished">Gira fort a l&apos;esquerra a %1.</translation>
    </message>
    <message>
        <source>Turn left.</source>
        <translation type="vanished">Gira a l&apos;esquerra.</translation>
    </message>
    <message>
        <source>Turn left onto %1.</source>
        <translation type="vanished">Gira a l&apos;esquerra a %1.</translation>
    </message>
    <message>
        <source>Turn slightly left.</source>
        <translation type="vanished">Gira lleugerament a l&apos;esquerra.</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1.</source>
        <translation type="vanished">Gira lleugerament a l&apos;esquerra a %1.</translation>
    </message>
    <message>
        <source>Reached waypoint.</source>
        <translation type="vanished">S&apos;ha arribat al punt del camí.</translation>
    </message>
    <message>
        <source>Head on.</source>
        <translation type="vanished">Cap endavant.</translation>
    </message>
    <message>
        <source>Head onto %1.</source>
        <translation type="vanished">Cap endavant a %1.</translation>
    </message>
    <message>
        <source>Enter the roundabout.</source>
        <translation type="vanished">Entra a la rotonda.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit.</source>
        <translation type="vanished">A la rotonda agafa la primera sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la primera sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit.</source>
        <translation type="vanished">A la rotonda agafa la segona sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la segona sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit.</source>
        <translation type="vanished">A la rotonda agafa la tercera sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la tercera sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit.</source>
        <translation type="vanished">A la rotonda agafa la quarta sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la quarta sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit.</source>
        <translation type="vanished">A la rotonda agafa la cinquena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la cinquena sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit.</source>
        <translation type="vanished">A la rotonda agafa la sisena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la sisena sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit.</source>
        <translation type="vanished">A la rotonda agafa la setena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la setena sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit.</source>
        <translation type="vanished">A la rotonda agafa la vuitena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la vuitena sortida a %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit.</source>
        <translation type="vanished">A la rotonda agafa la novena sortida.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit onto %1.</source>
        <translation type="vanished">A la rotonda agafa la novena sortida a %1.</translation>
    </message>
    <message>
        <source>Leave the roundabout.</source>
        <translation type="vanished">Surt de la rotonda.</translation>
    </message>
    <message>
        <source>Leave the roundabout onto %1.</source>
        <translation type="vanished">Surt de la rotonda a %1.</translation>
    </message>
    <message>
        <source>Stay on the roundabout.</source>
        <translation type="vanished">Roman a la rotonda.</translation>
    </message>
    <message>
        <source>Start at the end of the street.</source>
        <translation type="vanished">Comença al final del carrer.</translation>
    </message>
    <message>
        <source>Start at the end of %1.</source>
        <translation type="vanished">Comença al final de %1.</translation>
    </message>
    <message>
        <source>You have reached your destination.</source>
        <translation type="vanished">Has arribat a la teva destinació.</translation>
    </message>
    <message>
        <source>Don&apos;t know what to say for &apos;%1&apos;</source>
        <translation type="vanished">No sé què dir per a «%1»</translation>
    </message>
</context>
<context>
    <name>QGeoServiceProviderFactoryMapbox</name>
    <message>
        <source>Mapbox plugin requires &apos;mapbox.map_id&apos; and &apos;mapbox.access_token&apos; parameters.
Please visit https://www.mapbox.com</source>
        <translation type="vanished">El connector de Mapbox requereix els paràmetres «mapbox.map_id» i «mapbox.access_token».
Visiteu https://www.mapbox.com</translation>
    </message>
    <message>
        <source>Mapbox plugin requires a &apos;mapbox.access_token&apos; parameter.
Please visit https://www.mapbox.com</source>
        <translation>El connector de Mapbox requereix un paràmetre «mapbox.access_token».
Visiteu https://www.mapbox.com</translation>
    </message>
</context>
<context>
    <name>QGeoTileFetcherNokia</name>
    <message>
        <source>Mapping manager no longer exists</source>
        <translation>El gestor del mapatge ja no existeix</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMapOsm</name>
    <message>
        <source>Tiles Courtesy of &lt;a href=&apos;http://www.mapquest.com/&apos;&gt;MapQuest&lt;/a&gt;&lt;br/&gt;Data &amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt; contributors</source>
        <translation type="vanished">Quadrants cortesia de &lt;a href=&apos;http://www.mapquest.com/&apos;&gt;MapQuest&lt;/a&gt;&lt;br/&gt; &amp;copy; de les dades dels col·laboradors d&apos;&lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Maps &amp;copy; &lt;a href=&apos;http://www.thunderforest.com/&apos;&gt;Thunderforest&lt;/a&gt;&lt;br/&gt;Data &amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt; contributors</source>
        <translation type="vanished">Mapes &amp;copy; de &lt;a href=&apos;http://www.thunderforest.com/&apos;&gt;Thunderforest&lt;/a&gt;&lt;br/&gt;&amp;copy; de les dades dels col·laboradors d&apos;&lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;copy; &lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt; contributors</source>
        <translation type="vanished">&amp;copy; dels col·laboradors d&apos;&lt;a href=&apos;http://www.openstreetmap.org/copyright&apos;&gt;OpenStreetMap&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineMapbox</name>
    <message>
        <source>Custom</source>
        <translation type="vanished">Personalitzat</translation>
    </message>
    <message>
        <source>Mapbox custom map</source>
        <translation type="vanished">Mapa personalitzat de Mapbox</translation>
    </message>
    <message>
        <source>Street</source>
        <extracomment>Noun describing map type &apos;Street map&apos;</extracomment>
        <translation>Carrer</translation>
    </message>
    <message>
        <source>Light</source>
        <extracomment>Noun describing type of a map using light colors (weak contrast)</extracomment>
        <translation>Clar</translation>
    </message>
    <message>
        <source>Dark</source>
        <extracomment>Noun describing type of a map using dark colors</extracomment>
        <translation>Fosc</translation>
    </message>
    <message>
        <source>Satellite</source>
        <extracomment>Noun describing type of a map created by satellite</extracomment>
        <translation>Satèl·lit</translation>
    </message>
    <message>
        <source>Streets Satellite</source>
        <extracomment>Noun describing type of a street map created by satellite</extracomment>
        <translation>Carrers des de satèl·lit</translation>
    </message>
    <message>
        <source>Wheatpaste</source>
        <extracomment>Noun describing type of a map using wheat paste colors</extracomment>
        <translatorcomment>&quot;Wheat paste&quot; és un tipus de cola per enganxar cartells a les parets. Els cartells tenen colors molt bàsics (https://en.wikipedia.org/wiki/Wheatpaste).</translatorcomment>
        <translation>Colors bàsics</translation>
    </message>
    <message>
        <source>Streets Basic</source>
        <extracomment>Noun describing type of a basic street map</extracomment>
        <translation>Carrers bàsic</translation>
    </message>
    <message>
        <source>Comic</source>
        <extracomment>Noun describing type of a map using cartoon-style fonts</extracomment>
        <translation>Còmic</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <extracomment>Noun describing type of a map for outdoor activities</extracomment>
        <translation>Exteriors</translation>
    </message>
    <message>
        <source>Run Bike Hike</source>
        <extracomment>Noun describing type of a map for sports</extracomment>
        <translation>Córrer, bicicleta, excursió</translation>
    </message>
    <message>
        <source>Pencil</source>
        <extracomment>Noun describing type of a map drawn by pencil</extracomment>
        <translation>Llapis</translation>
    </message>
    <message>
        <source>Pirates</source>
        <extracomment>Noun describing type of a treasure map with pirate boat watermark</extracomment>
        <translation>Pirates</translation>
    </message>
    <message>
        <source>Emerald</source>
        <extracomment>Noun describing type of a map using emerald colors</extracomment>
        <translation>Maragda</translation>
    </message>
    <message>
        <source>High Contrast</source>
        <extracomment>Noun describing type of a map with high contrast</extracomment>
        <translation>Contrast alt</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineNokia</name>
    <message>
        <source>Street Map</source>
        <translation>Mapa de carrers</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode</source>
        <translation>Vista del mapa normal en el mode diürn</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Mapa de satèl·lit</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Vista del mapa de satèl·lit en el mode diürn</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Mapa del terreny</translation>
    </message>
    <message>
        <source>Terrain map view in daylight mode</source>
        <translation>Vista del mapa del terreny en el mode diürn</translation>
    </message>
    <message>
        <source>Hybrid Map</source>
        <translation>Mapa híbrid</translation>
    </message>
    <message>
        <source>Satellite map view with streets in daylight mode</source>
        <translation>Vista del mapa de satèl·lit amb els carrers en el mode diürn</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Mapa per al transport</translation>
    </message>
    <message>
        <source>Color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Vista del mapa amb el color reduït amb l&apos;esquema del transport públic en el mode diürn</translation>
    </message>
    <message>
        <source>Gray Street Map</source>
        <translation>Mapa de carrers en gris</translation>
    </message>
    <message>
        <source>Color-reduced map view in daylight mode</source>
        <translation>Vista del mapa amb el color reduït en el mode diürn</translation>
    </message>
    <message>
        <source>Mobile Street Map</source>
        <translation>Mapa de carrers per al mòbil</translation>
    </message>
    <message>
        <source>Mobile normal map view in daylight mode</source>
        <translation>Vista mòbil del mapa normal en el mode diürn</translation>
    </message>
    <message>
        <source>Mobile Terrain Map</source>
        <translation>Mapa del terreny per al mòbil</translation>
    </message>
    <message>
        <source>Mobile terrain map view in daylight mode</source>
        <translation>Vista mòbil del mapa del terreny en el mode diürn</translation>
    </message>
    <message>
        <source>Mobile Hybrid Map</source>
        <translation>Mapa híbrid per al mòbil</translation>
    </message>
    <message>
        <source>Mobile satellite map view with streets in daylight mode</source>
        <translation>Vista mòbil del mapa de satèl·lit amb els carrers en el mode diürn</translation>
    </message>
    <message>
        <source>Mobile Transit Map</source>
        <translation>Mapa del trànsit per al mòbil</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Vista mòbil del mapa amb el color reduït amb l&apos;esquema del transport públic en el mode diürn</translation>
    </message>
    <message>
        <source>Mobile Gray Street Map</source>
        <translation>Mapa de carrers en gris per al mòbil</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in daylight mode</source>
        <translation>Vista mòbil del mapa amb el color reduït en el mode diürn</translation>
    </message>
    <message>
        <source>Custom Street Map</source>
        <translation>Mapa de carrers personalitzat</translation>
    </message>
    <message>
        <source>Night Street Map</source>
        <translation>Mapa de carrers nocturn</translation>
    </message>
    <message>
        <source>Normal map view in night mode</source>
        <translation>Vista del mapa normal en el mode nocturn</translation>
    </message>
    <message>
        <source>Mobile Night Street Map</source>
        <translation>Mapa de carrers nocturn per al mòbil</translation>
    </message>
    <message>
        <source>Mobile normal map view in night mode</source>
        <translation>Vista del mapa normal per al mòbil en el mode nocturn</translation>
    </message>
    <message>
        <source>Gray Night Street Map</source>
        <translation>Mapa de carrers nocturn en gris</translation>
    </message>
    <message>
        <source>Color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Vista del mapa amb el color reduït en el mode nocturn (especialment usat per a mapes de fons)</translation>
    </message>
    <message>
        <source>Mobile Gray Night Street Map</source>
        <translation>Mapa de carrers nocturn en gris per al mòbil</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Vista mòbil del mapa amb el color reduït en el mode nocturn (especialment usat per a mapes de fons)</translation>
    </message>
    <message>
        <source>Pedestrian Street Map</source>
        <translation>Mapa de carrers per a vianants</translation>
    </message>
    <message>
        <source>Pedestrian map view in daylight mode</source>
        <translation>Vista del mapa per a vianants en el mode diürn</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Street Map</source>
        <translation>Mapa de carrers mòbil per a vianants</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in daylight mode for mobile usage</source>
        <translation>Vista mòbil del mapa per a vianants en el mode diürn</translation>
    </message>
    <message>
        <source>Pedestrian Night Street Map</source>
        <translation>Mapa de carrers nocturn per a vianants</translation>
    </message>
    <message>
        <source>Pedestrian map view in night mode</source>
        <translation>Vista mòbil del mapa normal per a vianants en el mode nocturn</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Night Street Map</source>
        <translation>Mapa de carrers mòbil per a vianants en el mode nocturn</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in night mode for mobile usage</source>
        <translation>Vista mòbil del mapa de carrers per a vianants en el mode nocturn</translation>
    </message>
    <message>
        <source>Car Navigation Map</source>
        <translation>Mapa per a la navegació en cotxe</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode for car navigation</source>
        <translation>Vista del mapa normal per a la navegació en cotxe en el mode diürn</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineOsm</name>
    <message>
        <source>Street Map</source>
        <translation>Mapa de carrers</translation>
    </message>
    <message>
        <source>Street map view in daylight mode</source>
        <translation>Vista del mapa de carrers en el mode diürn</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Mapa de satèl·lit</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Vista del mapa de satèl·lit en el mode diürn</translation>
    </message>
    <message>
        <source>Cycle Map</source>
        <translation>Mapa per a bicicleta</translation>
    </message>
    <message>
        <source>Cycle map view in daylight mode</source>
        <translation>Vista del mapa per a bicicleta en el mode diürn</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Mapa per al transport</translation>
    </message>
    <message>
        <source>Public transit map view in daylight mode</source>
        <translation>Vista del mapa per al transport públic en el mode diürn</translation>
    </message>
    <message>
        <source>Night Transit Map</source>
        <translation>Mapa nocturn per al transport</translation>
    </message>
    <message>
        <source>Public transit map view in night mode</source>
        <translation>Vista del mapa per al transport públic en el mode nocturn</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Mapa del terreny</translation>
    </message>
    <message>
        <source>Terrain map view</source>
        <translation>Vista del mapa del terreny</translation>
    </message>
    <message>
        <source>Hiking Map</source>
        <translation>Mapa per al senderisme</translation>
    </message>
    <message>
        <source>Hiking map view</source>
        <translation>Vista del mapa per al senderisme</translation>
    </message>
    <message>
        <source>Custom URL Map</source>
        <translation>URL personalitzat per al mapa</translation>
    </message>
    <message>
        <source>Custom url map view set via urlprefix parameter</source>
        <translation>Vista de l&apos;URL personalitzat per al mapa establert amb el paràmetre «urlprefix»</translation>
    </message>
</context>
<context>
    <name>QPlaceManagerEngineOsm</name>
    <message>
        <source>Aeroway</source>
        <translation>Mitjà aeri</translation>
    </message>
    <message>
        <source>Amenity</source>
        <translation>Servei</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Edifici</translation>
    </message>
    <message>
        <source>Highway</source>
        <translation>Carretera</translation>
    </message>
    <message>
        <source>Historic</source>
        <translation>Històric</translation>
    </message>
    <message>
        <source>Land use</source>
        <translation>Ús de la terra</translation>
    </message>
    <message>
        <source>Leisure</source>
        <translation>Oci</translation>
    </message>
    <message>
        <source>Man made</source>
        <translation>Fet per l&apos;home</translation>
    </message>
    <message>
        <source>Natural</source>
        <translation>Natural</translation>
    </message>
    <message>
        <source>Place</source>
        <translation>Lloc</translation>
    </message>
    <message>
        <source>Railway</source>
        <translation>Línia de ferrocarril</translation>
    </message>
    <message>
        <source>Shop</source>
        <translation>Botiga</translation>
    </message>
    <message>
        <source>Tourism</source>
        <translation>Turisme</translation>
    </message>
    <message>
        <source>Waterway</source>
        <translation>Via navegable</translation>
    </message>
    <message>
        <source>Network request error</source>
        <translation>Petició de xarxa errònia</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Error en analitzar la resposta</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyOsm</name>
    <message>
        <source>Communication error</source>
        <translation type="vanished">Error en la comunicació</translation>
    </message>
    <message>
        <source>Response parse error</source>
        <translation>Error en analitzar la resposta</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchSuggestionReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Error en analitzar la resposta</translation>
    </message>
</context>
<context>
    <name>QtLocationQML</name>
    <message>
        <source>Plugin property is not set.</source>
        <translation>El connector no s&apos;ha establert correctament.</translation>
    </message>
    <message>
        <source>Plugin Error (%1): %2</source>
        <translation>Error del connector (%1): %2</translation>
    </message>
    <message>
        <source>Plugin Error (%1): Could not instantiate provider</source>
        <translation>Error del connector (%1): No s&apos;ha pogut crear una instància del proveïdor</translation>
    </message>
    <message>
        <source>Plugin is not valid</source>
        <translation>El connector no és vàlid</translation>
    </message>
    <message>
        <source>Unable to initialize categories</source>
        <translation>No s&apos;han pogut inicialitzar les categories</translation>
    </message>
    <message>
        <source>Unable to create request</source>
        <translation>No s&apos;ha pogut crear la petició</translation>
    </message>
    <message>
        <source>Index &apos;%1&apos; out of range</source>
        <translation>L&apos;índex «%1» està fora de l&apos;interval</translation>
    </message>
    <message>
        <source>Qt Location requires app_id and token parameters.
Please register at https://developer.here.com/ to get your personal application credentials.</source>
        <translation type="vanished">Qt Location requereix els paràmetres «app_id» i «token».
Registreu-vos a https://developer.here.com/ per a obtenir les vostres credencials personals de l&apos;aplicació.</translation>
    </message>
    <message>
        <source>Qt Location requires apiKey parameter.
Please register at https://developer.here.com/ to get your personal application credentials.</source>
        <translation>El Qt Location requereix el paràmetre «apiKey».
Registreu-vos a https://developer.here.com/ per a obtenir les vostres credencials personals d&apos;aplicació.</translation>
    </message>
    <message>
        <source>Saving places is not supported.</source>
        <translation>No s&apos;admet desar els llocs.</translation>
    </message>
    <message>
        <source>Removing places is not supported.</source>
        <translation>No s&apos;admet eliminar els llocs.</translation>
    </message>
    <message>
        <source>Saving categories is not supported.</source>
        <translation>No s&apos;admet desar les categories.</translation>
    </message>
    <message>
        <source>Removing categories is not supported.</source>
        <translation>No s&apos;admet eliminar les categories.</translation>
    </message>
    <message>
        <source>Error parsing response.</source>
        <translation>Error en analitzar la resposta.</translation>
    </message>
    <message>
        <source>Network error.</source>
        <translation>Error de la xarxa.</translation>
    </message>
    <message>
        <source>Request was canceled.</source>
        <translation>S&apos;ha cancel·lat la sol·licitud.</translation>
    </message>
    <message>
        <source>The response from the service was not in a recognizable format.</source>
        <translation>La resposta del servei no estava en un format reconeixible.</translation>
    </message>
</context>
</TS>
